@@ -26,16 +26,21 @@ Tailbone Web API - Batch Views
 
 from __future__ import unicode_literals, absolute_import
 
+import logging
+
 import six
 
 from rattail.time import localtime
 from rattail.util import load_object
 
-from cornice import resource
+from cornice import resource, Service
 
 from tailbone.api import APIMasterView2 as APIMasterView
 
 
+log = logging.getLogger(__name__)
+
+
 class APIBatchMixin(object):
     """
     Base class for all API views which are meant to handle "batch" *and/or*
@@ -85,14 +90,11 @@ class APIBatchView(APIBatchMixin, APIMasterView):
 
     def normalize(self, batch):
 
-        created = batch.created
-        created = localtime(self.rattail_config, created, from_utc=True)
-        created = self.pretty_datetime(created)
+        created = localtime(self.rattail_config, batch.created, from_utc=True)
 
-        executed = batch.executed
-        if executed:
-            executed = localtime(self.rattail_config, executed, from_utc=True)
-            executed = self.pretty_datetime(executed)
+        executed = None
+        if batch.executed:
+            executed = localtime(self.rattail_config, batch.executed, from_utc=True)
 
         return {
             'uuid': batch.uuid,
@@ -103,11 +105,16 @@ class APIBatchView(APIBatchMixin, APIMasterView):
             'notes': batch.notes,
             'params': batch.params or {},
             'rowcount': batch.rowcount,
-            'created': created,
+            'created': six.text_type(created),
+            'created_display': self.pretty_datetime(created),
             'created_by_uuid': batch.created_by.uuid,
             'created_by_display': six.text_type(batch.created_by),
             'complete': batch.complete,
-            'executed': executed,
+            'status_code': batch.status_code,
+            'status_display': batch.STATUS.get(batch.status_code,
+                                               six.text_type(batch.status_code)),
+            'executed': six.text_type(executed) if executed else None,
+            'executed_display': self.pretty_datetime(executed) if executed else None,
             'executed_by_uuid': batch.executed_by_uuid,
             'executed_by_display': six.text_type(batch.executed_by or ''),
         }
@@ -210,25 +217,27 @@ class APIBatchView(APIBatchMixin, APIMasterView):
         if cls.supports_toggle_complete:
 
             # mark complete
-            config.add_route('{}.mark_complete'.format(route_prefix), '{}/{{uuid}}/mark-complete'.format(object_url_prefix))
-            config.add_view(cls, attr='mark_complete', route_name='{}.mark_complete'.format(route_prefix),
-                            permission='{}.edit'.format(permission_prefix),
-                            renderer='json')
+            mark_complete = Service(name='{}.mark_complete'.format(route_prefix),
+                                    path='{}/{{uuid}}/mark-complete'.format(object_url_prefix))
+            mark_complete.add_view('POST', 'mark_complete', klass=cls,
+                                   permission='{}.edit'.format(permission_prefix))
+            config.add_cornice_service(mark_complete)
 
             # mark incomplete
-            config.add_route('{}.mark_incomplete'.format(route_prefix), '{}/{{uuid}}/mark-incomplete'.format(object_url_prefix))
-            config.add_view(cls, attr='mark_incomplete', route_name='{}.mark_incomplete'.format(route_prefix),
-                            permission='{}.edit'.format(permission_prefix),
-                            renderer='json')
+            mark_incomplete = Service(name='{}.mark_incomplete'.format(route_prefix),
+                                      path='{}/{{uuid}}/mark-incomplete'.format(object_url_prefix))
+            mark_incomplete.add_view('POST', 'mark_incomplete', klass=cls,
+                                     permission='{}.edit'.format(permission_prefix))
+            config.add_cornice_service(mark_incomplete)
 
         if cls.supports_execute:
 
-            # execute
-            config.add_route('{}.execute'.format(route_prefix), '{}/{{uuid}}/execute'.format(object_url_prefix),
-                             request_method=('OPTIONS', 'POST'))
-            config.add_view(cls, attr='execute', route_name='{}.execute'.format(route_prefix),
-                            permission='{}.execute'.format(permission_prefix),
-                            renderer='json')
+            # execute batch
+            execute = Service(name='{}.execute'.format(route_prefix),
+                              path='{}/{{uuid}}/execute'.format(object_url_prefix))
+            execute.add_view('POST', 'execute', klass=cls,
+                             permission='{}.execute'.format(permission_prefix))
+            config.add_cornice_service(execute)
 
 
 # TODO: deprecate / remove this
@@ -264,6 +273,28 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
             'status_display': row.STATUS.get(row.status_code, six.text_type(row.status_code)),
         }
 
+    def update_object(self, row, data):
+        """
+        Supplements the default logic as follows:
+
+        Invokes the batch handler's ``refresh_row()`` method after updating the
+        row's field data per usual.
+        """
+        # update row per usual
+        row = super(APIBatchRowView, self).update_object(row, data)
+
+        # okay now we apply handler refresh logic
+        self.handler.refresh_row(row)
+        return row
+
+    def delete_object(self, row):
+        """
+        Overrides the default logic as follows:
+
+        Delegates deletion of the row to the batch handler.
+        """
+        self.handler.do_remove_row(row)
+
     def quick_entry(self):
         """
         View for handling "quick entry" user input, for a batch.
@@ -280,6 +311,9 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
         try:
             row = self.handler.quick_entry(self.Session(), batch, entry)
         except Exception as error:
+            log.warning("quick entry failed for '%s' batch %s: %s",
+                        self.handler.batch_key, batch.id_str, entry,
+                        exc_info=True)
             msg = six.text_type(error)
             if not msg and isinstance(error, NotImplementedError):
                 msg = "Feature is not implemented"
