@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -69,7 +69,8 @@ class Grid(object):
 
     def __init__(self, key, data, columns=None, width='auto', request=None, mobile=False,
                  model_class=None, model_title=None, model_title_plural=None,
-                 enums={}, labels={}, renderers={}, extra_row_class=None, linked_columns=[], url='#',
+                 enums={}, labels={}, assume_local_times=False, renderers={},
+                 extra_row_class=None, linked_columns=[], url='#',
                  joiners={}, filterable=False, filters={}, use_byte_string_filters=False,
                  sortable=False, sorters={}, default_sortkey=None, default_sortdir='asc',
                  pageable=False, default_pagesize=20, default_page=1,
@@ -102,6 +103,7 @@ class Grid(object):
         self.enums = enums or {}
 
         self.labels = labels or {}
+        self.assume_local_times = assume_local_times
         self.renderers = self.make_default_renderers(renderers or {})
         self.extra_row_class = extra_row_class
         self.linked_columns = linked_columns or []
@@ -407,7 +409,10 @@ class Grid(object):
             return self.render_boolean
 
         if isinstance(coltype, sa.DateTime):
-            return self.render_datetime
+            if self.assume_local_times:
+                return self.render_datetime_local
+            else:
+                return self.render_datetime
 
         if isinstance(coltype, GPCType):
             return self.render_gpc
@@ -1189,8 +1194,16 @@ class Grid(object):
         status_map = {}
         checked = []
 
+        # we check for 'all' method and if so, assume we have a Query;
+        # otherwise we assume it's something we can use len() with, which could
+        # be a list or a Paginator
+        if hasattr(raw_data, 'all'):
+            count = raw_data.count()
+        else:
+            count = len(raw_data)
+
         # iterate over data rows
-        for i in range(len(raw_data)):
+        for i in range(count):
             rowobj = raw_data[i]
             row = {}
 
@@ -1257,6 +1270,8 @@ class Grid(object):
             results['pages'] = self.pager.page_count
             results['first_item'] = self.pager.first_item
             results['last_item'] = self.pager.last_item
+        else:
+            results['total_items'] = count
 
         return results
 
