@@ -4,6 +4,8 @@ const NumericInput = {
         '<b-input',
         ':name="name"',
         ':value="value"',
+        '@focus="focus"',
+        '@blur="blur"',
         '@keydown.native="keyDown"',
         '@input="valueChanged"',
         '>',
@@ -18,6 +20,14 @@ const NumericInput = {
 
     methods: {
 
+        focus(event) {
+            this.$emit('focus', event)
+        },
+
+        blur(event) {
+            this.$emit('blur', event)
+        },
+
         keyDown(event) {
             // by default we only allow numeric keys, and general navigation
             // keys, but we might also allow Enter key
