@@ -37,6 +37,7 @@ from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import View
 from tailbone.auth import login_user, logout_user
+from tailbone.config import global_help_url
 
 
 class UserLogin(colander.MappingSchema):
@@ -128,6 +129,7 @@ class AuthenticationView(View):
             'referrer': referrer,
             'image_url': image_url,
             'use_buefy': use_buefy,
+            'help_url': global_help_url(self.rattail_config),
         }
 
     def authenticate_user(self, username, password):
@@ -172,6 +174,10 @@ class AuthenticationView(View):
         if not self.request.user:
             return self.redirect(self.request.route_url('home'))
 
+        if self.user_is_protected(self.request.user):
+            self.request.session.flash("Cannot change password for user: {}".format(self.request.user))
+            return self.redirect(self.request.get_referrer())
+
         use_buefy = self.get_use_buefy()
         schema = ChangePassword().bind(user=self.request.user)
         form = forms.Form(schema=schema, request=self.request, use_buefy=use_buefy)
