@@ -186,14 +186,6 @@ class VendorCatalogsView(FileBatchMasterView):
         if not self.creating:
             f.set_readonly('effective')
 
-    def render_vendor(self, batch, field):
-        vendor = batch.vendor
-        if not vendor:
-            return ""
-        text = "({}) {}".format(vendor.id, vendor.name)
-        url = self.request.route_url('vendors.view', uuid=vendor.uuid)
-        return tags.link_to(text, url)
-
     def get_batch_kwargs(self, batch):
         kwargs = super(VendorCatalogsView, self).get_batch_kwargs(batch)
         kwargs['parser_key'] = batch.parser_key
