@@ -1,23 +1,23 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2016 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
 #  Rattail is free software: you can redistribute it and/or modify it under the
-#  terms of the GNU Affero General Public License as published by the Free
-#  Software Foundation, either version 3 of the License, or (at your option)
-#  any later version.
+#  terms of the GNU General Public License as published by the Free Software
+#  Foundation, either version 3 of the License, or (at your option) any later
+#  version.
 #
 #  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
-#  more details.
+#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+#  details.
 #
-#  You should have received a copy of the GNU Affero General Public License
-#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU General Public License along with
+#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
 """
@@ -29,18 +29,16 @@ from __future__ import unicode_literals, absolute_import
 import os
 import datetime
 
+import six
+
 from rattail.db import model
 from rattail.bouncer import get_handler
 from rattail.bouncer.config import get_profile_keys
 
-import formalchemy
 from pyramid.response import FileResponse
-from webhelpers.html import literal
+from webhelpers2.html import HTML, tags
 
-from tailbone import newgrids as grids
-from tailbone.db import Session
 from tailbone.views import MasterView
-from tailbone.forms.renderers.bouncer import BounceMessageFieldRenderer
 
 
 class EmailBouncesView(MasterView):
@@ -53,69 +51,100 @@ class EmailBouncesView(MasterView):
     creatable = False
     editable = False
 
+    labels = {
+        'config_key': "Source",
+        'bounce_recipient_address': "Bounced To",
+        'intended_recipient_address': "Intended For",
+    }
+
+    grid_columns = [
+        'config_key',
+        'bounced',
+        'bounce_recipient_address',
+        'intended_recipient_address',
+        'processed_by',
+    ]
+
     def __init__(self, request):
         super(EmailBouncesView, self).__init__(request)
-        self.handler_options = [('', '(any)')] + sorted(get_profile_keys(self.rattail_config))
+        self.handler_options = sorted(get_profile_keys(self.rattail_config))
 
     def get_handler(self, bounce):
         return get_handler(self.rattail_config, bounce.config_key)
 
     def configure_grid(self, g):
-        g.joiners['processed_by'] = lambda q: q.outerjoin(model.User)
+        super(EmailBouncesView, self).configure_grid(g)
+
+        g.filters['config_key'].set_choices(self.handler_options)
         g.filters['config_key'].default_active = True
         g.filters['config_key'].default_verb = 'equal'
-        g.filters['config_key'].label = "Source"
-        g.filters['config_key'].set_value_renderer(grids.filters.ChoiceValueRenderer(self.handler_options))
-        g.filters['bounce_recipient_address'].label = "Bounced To"
-        g.filters['intended_recipient_address'].label = "Intended For"
+
+        g.joiners['processed_by'] = lambda q: q.outerjoin(model.User)
         g.filters['processed'].default_active = True
         g.filters['processed'].default_verb = 'is_null'
         g.filters['processed_by'] = g.make_filter('processed_by', model.User.username)
         g.sorters['processed_by'] = g.make_sorter(model.User.username)
-        g.default_sortkey = 'bounced'
-        g.default_sortdir = 'desc'
-        g.configure(
-            include=[
-                g.config_key.label("Source"),
-                g.bounced,
-                g.bounce_recipient_address.label("Bounced To"),
-                g.intended_recipient_address.label("Intended For"),
-                g.processed_by,
-            ],
-            readonly=True)
+        g.set_sort_defaults('bounced', 'desc')
 
-    def configure_fieldset(self, fs):
-        bounce = fs.model
-        handler = self.get_handler(bounce)
-        fs.append(formalchemy.Field('message',
-                                    value=handler.msgpath(bounce),
-                                    renderer=BounceMessageFieldRenderer.new(self.request, handler)))
-        fs.append(formalchemy.Field('links',
-                                    value=list(handler.make_links(Session(), bounce.intended_recipient_address)),
-                                    renderer=LinksFieldRenderer))
-        fs.configure(
-            include=[
-                fs.config_key.label("Source"),
-                fs.message,
-                fs.bounced,
-                fs.bounce_recipient_address.label("Bounced To"),
-                fs.intended_recipient_address.label("Intended For"),
-                fs.links,
-                fs.processed,
-                fs.processed_by,
-            ],
-            readonly=True)
+        g.set_label('bounce_recipient_address', "Bounced To")
+        g.set_label('intended_recipient_address', "Intended For")
+
+        g.set_link('bounced')
+        g.set_link('intended_recipient_address')
+
+    def configure_form(self, f):
+        super(EmailBouncesView, self).configure_form(f)
+        bounce = f.model_instance
+        f.set_renderer('message', self.render_message_file)
+        f.set_renderer('links', self.render_links)
+        f.fields = [
+            'config_key',
+            'message',
+            'bounced',
+            'bounce_recipient_address',
+            'intended_recipient_address',
+            'links',
+            'processed',
+            'processed_by',
+        ]
         if not bounce.processed:
-            del fs.processed
-            del fs.processed_by
+            f.remove_field('processed')
+            f.remove_field('processed_by')
+
+    def render_links(self, bounce, field):
+        handler = self.get_handler(bounce)
+        value = list(handler.make_links(self.Session(), bounce.intended_recipient_address))
+        if not value:
+            return "n/a"
+
+        links = []
+        for link in value:
+            label = HTML.literal("{}:&nbsp; ".format(link.type))
+            anchor = tags.link_to(link.title, link.url, target='_blank')
+            links.append(HTML.tag('li', label + anchor))
+
+        return HTML.tag('ul', HTML.literal('').join(links))
+
+    def render_message_file(self, bounce, field):
+        handler = self.get_handler(bounce)
+        path = handler.msgpath(bounce)
+        if not path:
+            return ""
+
+        url = self.get_action_url('download', bounce)
+        return self.render_file_field(path, url)
 
     def template_kwargs_view(self, **kwargs):
         bounce = kwargs['instance']
         kwargs['bounce'] = bounce
         handler = self.get_handler(bounce)
         kwargs['handler'] = handler
-        with open(handler.msgpath(bounce), 'rb') as f:
-            kwargs['message'] = f.read()
+        path = handler.msgpath(bounce)
+        if os.path.exists(path):
+            with open(path, 'rb') as f:
+                kwargs['message'] = f.read()
+        else:
+            kwargs['message'] = "(file not found)"
         return kwargs
 
     def process(self):
@@ -146,13 +175,15 @@ class EmailBouncesView(MasterView):
         handler = self.get_handler(bounce)
         path = handler.msgpath(bounce)
         response = FileResponse(path, request=self.request)
-        response.headers[b'Content-Length'] = str(os.path.getsize(path))
+        response.headers[b'Content-Length'] = six.binary_type(os.path.getsize(path))
         response.headers[b'Content-Disposition'] = b'attachment; filename="bounce.eml"'
         return response
 
     @classmethod
     def defaults(cls, config):
 
+        config.add_tailbone_permission_group('emailbounces', "Email Bounces", overwrite=False)
+
         # mark bounce as processed
         config.add_route('emailbounces.process', '/email-bounces/{uuid}/process')
         config.add_view(cls, attr='process', route_name='emailbounces.process',
@@ -177,19 +208,5 @@ class EmailBouncesView(MasterView):
         cls._defaults(config)
 
 
-class LinksFieldRenderer(formalchemy.FieldRenderer):
-
-    def render_readonly(self, **kwargs):
-        value = self.raw_value
-        if not value:
-            return 'n/a'
-        html = literal('<ul>')
-        for link in value:
-            html += literal('<li>{0}:&nbsp; <a href="{1}" target="_blank">{2}</a></li>'.format(
-                link.type, link.url, link.title))
-        html += literal('</ul>')
-        return html
-
-
 def includeme(config):
     EmailBouncesView.defaults(config)
