@@ -44,6 +44,7 @@ from tailbone.forms.common import Feedback
 from tailbone.db import Session
 from tailbone.views import View
 from tailbone.util import set_app_theme
+from tailbone.config import global_help_url
 
 
 class CommonView(View):
@@ -66,10 +67,14 @@ class CommonView(View):
             'tailbone', 'main_image_url',
             default=self.request.static_url('tailbone:static/img/home_logo.png'))
 
+        use_buefy = self.get_use_buefy()
         context = {
             'image_url': image_url,
-            'use_buefy': self.get_use_buefy(),
+            'use_buefy': use_buefy,
+            'help_url': global_help_url(self.rattail_config),
         }
+        if use_buefy:
+            context['index_title'] = self.rattail_config.node_title()
 
         if self.expose_quickie_search:
             context['quickie'] = self.get_quickie_context()
