@@ -42,7 +42,7 @@ from tailbone.db import Session
 from tailbone.auth import logout_user
 from tailbone.progress import SessionProgress
 from tailbone.util import should_use_buefy
-from tailbone.config import legacy_mobile_enabled
+from tailbone.config import legacy_mobile_enabled, protected_usernames
 
 
 class View(object):
@@ -76,6 +76,14 @@ class View(object):
         """
         return getattr(self.request, 'rattail_config', None)
 
+    def get_rattail_app(self):
+        """
+        Returns the  Rattail ``AppHandler`` instance, creating it if necessary.
+        """
+        if not hasattr(self, 'rattail_app'):
+            self.rattail_app = self.rattail_config.get_app()
+        return self.rattail_app
+
     def forbidden(self):
         """
         Convenience method, to raise a HTTP 403 Forbidden exception.
@@ -110,6 +118,20 @@ class View(object):
             if uuid:
                 return Session.query(model.User).get(uuid)
 
+    def user_is_protected(self, user):
+        """
+        This logic will consult the settings for a list of "protected"
+        usernames, which should require root privileges to edit.  If the given
+        ``user`` object is represented in this list, it is considered to be
+        protected and this method will return ``True``; otherwise it returns
+        ``False``.
+        """
+        if not hasattr(self, 'protected_usernames'):
+            self.protected_usernames = protected_usernames(self.rattail_config)
+        if self.protected_usernames and user.username in self.protected_usernames:
+            return True
+        return False
+
     def redirect(self, url, **kwargs):
         """
         Convenience method to return a HTTP 302 response.
@@ -144,7 +166,7 @@ class View(object):
         return render_to_response('json', data,
                                   request=self.request)
 
-    def file_response(self, path):
+    def file_response(self, path, filename=None):
         """
         Returns a generic FileResponse from the given path
         """
@@ -152,9 +174,10 @@ class View(object):
             return self.notfound()
         response = FileResponse(path, request=self.request)
         response.content_length = os.path.getsize(path)
-        filename = os.path.basename(path)
-        if six.PY2:
-            filename = filename.encode('ascii', 'replace')
+        if not filename:
+            filename = os.path.basename(path)
+            if six.PY2:
+                filename = filename.encode('ascii', 'replace')
         response.content_disposition = str('attachment; filename="{}"'.format(filename))
         return response
 
