@@ -385,14 +385,17 @@ class CustomersView(MasterView):
 
     @classmethod
     def defaults(cls, config):
+        cls._defaults(config)
+        cls._customer_defaults(config)
+
+    @classmethod
+    def _customer_defaults(cls, config):
         route_prefix = cls.get_route_prefix()
         url_prefix = cls.get_url_prefix()
         permission_prefix = cls.get_permission_prefix()
         model_key = cls.get_model_key()
         model_title = cls.get_model_title()
 
-        cls._defaults(config)
-
         # detach person
         if cls.people_detachable:
             config.add_tailbone_permission(permission_prefix, '{}.detach_person'.format(permission_prefix),
