@@ -164,15 +164,21 @@ class EmployeesView(MasterView):
         if employee.status == self.enum.EMPLOYEE_STATUS_FORMER:
             return 'warning'
 
+    def is_employee_protected(self, employee):
+        for user in employee.person.users:
+            if self.user_is_protected(user):
+                return True
+        return False
+
     def editable_instance(self, employee):
-        if self.rattail_config.demo():
-            return not bool(employee.user and employee.user.username == 'chuck')
-        return True
+        if self.request.is_root:
+            return True
+        return not self.is_employee_protected(employee)
 
     def deletable_instance(self, employee):
-        if self.rattail_config.demo():
-            return not bool(employee.user and employee.user.username == 'chuck')
-        return True
+        if self.request.is_root:
+            return True
+        return not self.is_employee_protected(employee)
 
     def configure_form(self, f):
         super(EmployeesView, self).configure_form(f)
