@@ -102,9 +102,6 @@ class ProductsView(MasterView):
         'size',
         'department',
         'vendor',
-        'cost',
-        'true_cost',
-        'true_margin',
         'regular_price',
         'current_price',
     ]
@@ -124,6 +121,7 @@ class ProductsView(MasterView):
         'default_pack',
         'case_size',
         'weighed',
+        'average_weight',
         'department',
         'subdepartment',
         'category',
@@ -1004,8 +1002,8 @@ class ProductsView(MasterView):
             history['changed'] = six.text_type(changed)
             history['changed_display_html'] = raw_datetime(self.rattail_config, changed)
             user = history.pop('changed_by')
-            history['changed_by_uuid'] = user.uuid
-            history['changed_by_display'] = six.text_type(user)
+            history['changed_by_uuid'] = user.uuid if user else None
+            history['changed_by_display'] = six.text_type(user or "??")
             jsdata.append(history)
         return jsdata
 
