@@ -54,7 +54,9 @@ class PurchaseView(MasterView):
         'department',
         'buyer',
         'date_ordered',
+        'po_total',
         'date_received',
+        'invoice_total',
         'invoice_number',
         'status',
     ]
@@ -177,7 +179,13 @@ class PurchaseView(MasterView):
         g.filters['status'].verbs = ['equal', 'not_equal', 'is_any']
         g.filters['status'].default_verb = 'is_any'
 
+        g.set_type('po_total', 'currency')
+        g.set_type('invoice_total', 'currency')
         g.set_label('invoice_number', "Invoice No.")
+        g.set_link('date_ordered')
+        g.set_link('po_total')
+        g.set_link('date_received')
+        g.set_link('invoice_total')
 
     def configure_form(self, f):
         super(PurchaseView, self).configure_form(f)
