@@ -203,9 +203,12 @@ class PurchasingBatchView(BatchMasterView):
                                            default_active=True, default_verb='contains')
         g.sorters['buyer'] = g.make_sorter(model.Person.display_name)
 
-        if self.request.has_perm('{}.execute'.format(self.get_permission_prefix())):
-            g.filters['complete'].default_active = True
-            g.filters['complete'].default_verb = 'is_true'
+        # TODO: we used to include the 'complete' filter by default, but it
+        # seems to likely be confusing for newcomers, so it is no longer
+        # default.  not sure if there are any other implications...?
+        # if self.request.has_perm('{}.execute'.format(self.get_permission_prefix())):
+        #     g.filters['complete'].default_active = True
+        #     g.filters['complete'].default_verb = 'is_true'
 
         # invoice_total
         g.set_type('invoice_total', 'currency')
@@ -309,7 +312,9 @@ class PurchasingBatchView(BatchMasterView):
                 f.set_node('department_uuid', colander.String())
                 dept_options = self.get_department_options()
                 dept_values = [(v, k) for k, v in dept_options]
+                dept_values.insert(0, ('', "(unspecified)"))
                 f.set_widget('department_uuid', dfwidget.SelectWidget(values=dept_values))
+                f.set_required('department_uuid', False)
                 f.set_label('department_uuid', "Department")
         else:
             f.set_readonly('department')
@@ -328,8 +333,9 @@ class PurchasingBatchView(BatchMasterView):
                             buyer_display = six.text_type(buyer)
                 elif self.creating:
                     buyer = self.request.user.employee
-                    buyer_display = six.text_type(buyer)
-                    f.set_default('buyer_uuid', buyer.uuid)
+                    if buyer:
+                        buyer_display = six.text_type(buyer)
+                        f.set_default('buyer_uuid', buyer.uuid)
                 elif self.editing:
                     buyer_display = six.text_type(batch.buyer or '')
                 buyers_url = self.request.route_url('employees.autocomplete')
