@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -130,6 +130,7 @@ class ReceivingBatchView(PurchasingBatchView):
     model_title_plural = "Receiving Batches"
     index_title = "Receiving"
     downloadable = True
+    bulk_deletable = True
     rows_editable = True
     mobile_creatable = True
     mobile_rows_filterable = True
@@ -200,6 +201,7 @@ class ReceivingBatchView(PurchasingBatchView):
         'truck_dump_status',
         'rowcount',
         'order_quantities_known',
+        'receiving_complete',
         'complete',
         'executed',
         'executed_by',
@@ -639,9 +641,6 @@ class ReceivingBatchView(PurchasingBatchView):
                                                    default_value=default_status)
         return filters
 
-    def get_purchase(self, uuid):
-        return self.Session.query(model.Purchase).get(uuid)
-
     def mobile_create(self):
         """
         Mobile view for creating a new receiving batch
@@ -759,9 +758,9 @@ class ReceivingBatchView(PurchasingBatchView):
         Assign the original purchase order to the given batch.  Default
         behavior assumes a Rattail Purchase object is what we're after.
         """
-        purchase = self.get_purchase(po_form.validated[self.purchase_order_fieldname])
-        if isinstance(purchase, model.Purchase):
-            batch.purchase_uuid = purchase.uuid
+        purchase = self.handler.assign_purchase_order(
+            batch, po_form.validated[self.purchase_order_fieldname],
+            session=self.Session())
 
         department = self.department_for_purchase(purchase)
         if department:
@@ -1805,14 +1804,16 @@ class ReceivingBatchView(PurchasingBatchView):
         instance_url_prefix = cls.get_instance_url_prefix()
         model_key = cls.get_model_key()
         permission_prefix = cls.get_permission_prefix()
+        legacy_mobile = cls.legacy_mobile_enabled(rattail_config)
 
         # row-level receiving
         config.add_route('{}.receive_row'.format(route_prefix), '{}/{{uuid}}/rows/{{row_uuid}}/receive'.format(url_prefix))
         config.add_view(cls, attr='receive_row', route_name='{}.receive_row'.format(route_prefix),
                         permission='{}.edit_row'.format(permission_prefix))
-        config.add_route('mobile.{}.receive_row'.format(route_prefix), '/mobile{}/{{uuid}}/rows/{{row_uuid}}/receive'.format(url_prefix))
-        config.add_view(cls, attr='mobile_receive_row', route_name='mobile.{}.receive_row'.format(route_prefix),
-                        permission='{}.edit_row'.format(permission_prefix))
+        if legacy_mobile:
+            config.add_route('mobile.{}.receive_row'.format(route_prefix), '/mobile{}/{{uuid}}/rows/{{row_uuid}}/receive'.format(url_prefix))
+            config.add_view(cls, attr='mobile_receive_row', route_name='mobile.{}.receive_row'.format(route_prefix),
+                            permission='{}.edit_row'.format(permission_prefix))
 
         # declare credit for row
         config.add_route('{}.declare_credit'.format(route_prefix), '{}/{{uuid}}/rows/{{row_uuid}}/declare-credit'.format(url_prefix))
