@@ -50,6 +50,14 @@ class StoresView(MasterView):
         'email',
     ]
 
+    form_fields = [
+        'id',
+        'name',
+        'phone',
+        'email',
+        'database_key',
+    ]
+
     labels = {
         'id':           "ID",
         'phone':        "Phone Number",
