@@ -42,7 +42,6 @@ from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import MasterView
 from tailbone.views.principal import PrincipalMasterView, PermissionsRenderer
-from tailbone.config import protected_usernames
 
 
 class UsersView(PrincipalMasterView):
@@ -154,23 +153,6 @@ class UsersView(PrincipalMasterView):
             return True
         return not self.user_is_protected(user)
 
-    def user_is_protected(self, user):
-        """
-        This logic will consult the settings, for a list of "protected"
-        usernames, which should require root privileges to edit.  If no setting
-        is found, or the given ``user`` is not represented in the setting, then
-        edit is allowed.
-
-        But if there is a setting, and the ``user`` is represented in it, then
-        this method will return ``True`` only if the "current" app user is
-        "root", otherwise will return ``False``.
-        """
-        if not hasattr(self, 'protected_usernames'):
-            self.protected_usernames = protected_usernames(self.rattail_config)
-        if self.protected_usernames and user.username in self.protected_usernames:
-            return True
-        return False
-
     def unique_username(self, node, value):
         query = self.Session.query(model.User)\
                             .filter(model.User.username == value)
