@@ -89,10 +89,6 @@ class VendorsView(MasterView):
         super(VendorsView, self).configure_form(f)
         vendor = f.model_instance
 
-        f.set_label('lead_time_days', "Lead Time in Days")
-
-        f.set_label('order_interval', "Order Interval in Days")
-
         # default_phone
         f.set_renderer('default_phone', self.render_default_phone)
         if not self.creating and vendor.phones:
